@@ -40,3 +40,13 @@ Error in source("basicModel.R") : basicModel.R:95:1: unexpected symbol
 4:             Mq$DATA$ixs$clust <- data$ixQ
 5:             Mq
 
+
+## 7 don't highlight dates
+       id              lat             lon                         obs_date  
+ Min.   :  1.00   Min.   :21.57   Min.   :-179.88   01/02/1997 04:16:53:  1  
+ 1st Qu.: 99.25   1st Qu.:24.36   1st Qu.:-147.38   01/02/1997 05:56:25:  1  
+ Median :197.50   Median :25.64   Median :-119.64   01/04/1997 17:41:54:  1  
+ Mean   :197.50   Mean   :27.21   Mean   : -21.52   01/05/1997 17:20:07:  1  
+ 3rd Qu.:295.75   3rd Qu.:27.41   3rd Qu.: 153.66   01/06/1997 04:31:13:  1  
+ Max.   :394.00   Max.   :39.84   Max.   : 179.93   01/06/1997 06:12:56:  1  
+                                                    (Other)            :388  
