@@ -79,13 +79,13 @@
     (modify-syntax-entry ?\# "<"  table)
     (modify-syntax-entry ?\n ">"  table)
     table)
-  "Syntax table for gretl-mode")
+  "Syntax table for `gretl-mode'.")
 
 ;; syntax table that holds within strings
 (defvar gretl-mode-string-syntax-table
   (let ((table (make-syntax-table)))
     table)
-  "Syntax table for gretl-mode")
+  "Syntax table for `gretl-mode' that holds within strings.")
 
 (defcustom gretl-continuation-offset 4
   "*Extra indentation applied to Gretl continuation lines."
@@ -391,7 +391,6 @@ end keywords as associated values.")
     (indent-line-to
      (or (and (ess-inside-string-p (point-at-bol)) 0)
 	 (save-excursion (ignore-errors (gretl-form-indent)))
-         (save-excursion (ignore-errors (gretl-paren-indent)))
          (save-excursion
            (let ((endtok (progn
                            (beginning-of-line)
@@ -446,14 +445,14 @@ end keywords as associated values.")
 
 ;; (defun gretl-send-string-function (process string visibly)
 ;;   (let ((gretl-process (get-process "gretlcli")))
-;;     (process-send-string process (format inferior-ess-load-command file)))
+;;     (process-send-string process (format ess-load-command file)))
 
 
 ;; (defun gretl-send-string-function (process string visibly)
 ;;   (let ((file (concat temporary-file-directory "gretl_eval_region.inp")))
 ;;     (with-temp-file file
 ;;       (insert string))
-;;     (process-send-string process (format inferior-ess-load-command file))))
+;;     (process-send-string process (format ess-load-command file))))
 
 (defun gretl--get-words-from-command (command start-reg end-reg)
   (with-current-buffer (ess-command command)
@@ -498,7 +497,7 @@ end keywords as associated values.")
     (inferior-ess-program		. "gretlcli")
     (inferior-ess-font-lock-defaults	. gretl-font-lock-defaults)
     (ess-get-help-topics-function	. 'gretl-get-help-topics-function)
-    (inferior-ess-load-command		. "open \"%s\"\n")
+    (ess-load-command   		. "open \"%s\"\n")
     ;; (ess-dump-error-re			. "in \\w* at \\(.*\\):[0-9]+")
     ;; (ess-error-regexp			. "\\(^\\s-*at\\s-*\\(?3:.*\\):\\(?2:[0-9]+\\)\\)")
     ;; (ess-error-regexp-alist		. ess-gretl-error-regexp-alist)
@@ -552,6 +551,7 @@ been created using the variable `ess-r-versions'."
   :group 'ess-gretl
   :type 'string)
 
+(defvar gretl-basic-offset 4)
 
 ;;;###autoload
 (defun gretl-mode  (&optional proc-name)
@@ -570,7 +570,6 @@ been created using the variable `ess-r-versions'."
   (set (make-local-variable 'end-of-defun-function) 'ess-end-of-function)
   ;; (local-set-key  "\t" 'gretl-indent-line) ;; temp workaround
   ;; (set (make-local-variable 'indent-line-function) 'gretl-indent-line)
-  (set (make-local-variable 'gretl-basic-offset) 4)
  ;; (ess-imenu-gretl)
   (run-hooks 'gretl-mode-hook))
 
@@ -596,7 +595,7 @@ to gretl, put them in the variable `inferior-gretl-args'."
     (ess-write-to-dribble-buffer   ;; for debugging only
      (format
       "\n(Gretl): ess-dialect=%s, buf=%s"
-      ess-dialect (current-buffer) start-args current-prefix-arg))
+      ess-dialect (current-buffer)))
     (let* ((r-start-args
 	    (concat inferior-gretl-args " " ; add space just in case
 		    (if start-args
@@ -605,15 +604,7 @@ to gretl, put them in the variable `inferior-gretl-args'."
 				 inferior-gretl-args
 				 "'] ? "))
 		      nil))))
-      (inferior-ess r-start-args) ;; -> .. (ess-multi ...) -> .. (inferior-ess-mode) ..
-;;      (ess-tb-start)
-      ;;   (set (make-local-variable 'font-lock-syntactic-keywords)
-      ;;        (list
-      ;; 	(list gretl-char-regex 2
-      ;; 	      gretl-mode-char-syntax-table)
-      ;; ;        (list gretl-string-regex 0
-      ;; ;              gretl-mode-string-syntax-table)
-      ;; ))
+      (inferior-ess r-start-args) 
       (set (make-local-variable 'indent-line-function) 'gretl-indent-line)
       (set (make-local-variable 'gretl-basic-offset) 4)
       (setq indent-tabs-mode nil)
@@ -662,3 +653,7 @@ to gretl, put them in the variable `inferior-gretl-args'."
 
 (provide 'ess-gretl)
 ;; (provide 'ess-gretl)
+
+(provide 'ess-gretl)
+
+;;; ess-gretl.el ends here
