@@ -1,6 +1,6 @@
 ;;; ess-r-a.el -- Possible local customizations for R with ESS.
 
-;; Copyright (C) 1997--2005 A.J. Rossini, Rich M. Heiberger, Martin
+;; Copyright (C) 1997--2005 A.J. Rossini, Richard M. Heiberger, Martin
 ;;      Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
 
 ;; Author: A.J. Rossini <blindglobe@gmail.com>
@@ -39,8 +39,7 @@
 ;; with vsize set to (for example) 40M, and nsize set to 600000.
 (defalias 'essr
   (read-kbd-macro
-   "C-u M-x R RET - - vsize SPC 40M SPC - - nsize SPC 600000 2*RET"))
-;; "SPC" must be "=" in future versions of R (works from 0.99 on)
+   "C-u M-x R RET - - vsize = 40M SPC - - nsize = 600000 2*RET"))
 
 (defun ess-r-do-region (start end &optional message)
   "Send the current region to R via AppleScript."
