@@ -42,16 +42,14 @@ ess-process is running as an ordinary inferior process.  Alway
 nil on Unix machines."
   (interactive)
   (if ess-microsoft-p
-      (let ((ess-ddeclient (ess-get-process-variable
-                            ess-local-process-name 'inferior-ess-ddeclient)))
+      (let ((ess-ddeclient (ess-get-process-variable 'inferior-ess-ddeclient)))
         (if (not (equal ess-ddeclient (default-value 'inferior-ess-ddeclient)))
             ess-ddeclient))))
 
 (defun ess-eval-region-execdde (start end even-empty)
   "Loop through lines in region and send them to ESS via execdde."
   (setq ;; set the following variables for the current ddeESS process.
-   inferior-ess-ddeclient (ess-get-process-variable
-                           ess-current-process-name 'inferior-ess-ddeclient)
+   inferior-ess-ddeclient (ess-get-process-variable 'inferior-ess-ddeclient)
    )
   (write-region start end ess-command-file nil nil 'no-message)
   (call-process-shell-command
@@ -77,12 +75,9 @@ nil on Unix machines."
 (defun ess-eval-region-ddeclient (start end even-empty)
   "Loop through lines in region and send them to ESS via ddeclient."
   (setq ;; set the following variables for the current ddeESS process.
-   inferior-ess-ddeclient (ess-get-process-variable
-                           ess-current-process-name 'inferior-ess-ddeclient)
-   inferior-ess-client-name (ess-get-process-variable
-                             ess-current-process-name 'inferior-ess-client-name)
-   inferior-ess-client-command (ess-get-process-variable
-                                ess-current-process-name 'inferior-ess-client-command))
+   inferior-ess-ddeclient (ess-get-process-variable 'inferior-ess-ddeclient)
+   inferior-ess-client-name (ess-get-process-variable 'inferior-ess-client-name)
+   inferior-ess-client-command (ess-get-process-variable 'inferior-ess-client-command))
   (narrow-to-region start end)
   (goto-char (point-min))
 
@@ -186,9 +181,7 @@ You may ignore the 'options' error in this buffer.\n\n")
     (set-buffer (find-file-noselect ess-command-file 'nowarn))
     (erase-buffer)
     (setq ;; set the following variables for the current ddeESS process.
-     inferior-ess-language-start (ess-get-process-variable
-                                  ess-current-process-name
-                                  'inferior-ess-language-start))
+     inferior-ess-language-start (ess-get-process-variable 'inferior-ess-language-start))
     (if inferior-ess-language-start
         (insert inferior-ess-language-start))
     (if inferior-ess-language-start-rgui
