@@ -1,6 +1,6 @@
 ;;; ess-sp3-d.el --- S-PLUS 3.x customization
 
-;; Copyright (C) 1997--2004 A.J. Rossini, Rich M. Heiberger, Martin
+;; Copyright (C) 1997--2004 A.J. Rossini, Richard M. Heiberger, Martin
 ;;      Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
 
 ;; Author: A.J. Rossini <rossini@u.washington.edu>
@@ -46,7 +46,7 @@
      (ess-loop-timeout                  . ess-S-loop-timeout);fixme: dialect spec.
      (ess-object-name-db-file           . "ess-s+3-namedb.el" )
      (inferior-ess-program              . inferior-S+3-program-name)
-     (inferior-ess-help-command         . "help(\"%s\",pager=\"cat\",window=F)\n")
+     (inferior-ess-help-command         . "help(\"%s\", pager=\"cat\", window=FALSE)\n")
      (inferior-ess-help-filetype . nil)
      (inferior-ess-search-list-command  . "search()\n")
      (inferior-ess-start-file           . nil) ;"~/.ess-S+3")
